<?php
/**
 * The Template for displaying store sidebar category.
 *
 * @package WCfM Markeplace Views Store Sidebar Category
 *
 * For edit coping this to yourtheme/wcfm/store/widgets
 *
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

global $WCFM, $WCFMmp;

?>

<div id="wcfmmp-stores-wrap">
	<div class="wcfmmp-stores-content">
		<?php if ( !empty( $stores )  ) : ?>
			<ul class="wcfmmp-store-wrap">
				<?php
				foreach ( $stores as $store_id => $store_name ) {
					$store_user      = wcfmmp_get_store( $store_id );
					$store_info      = $store_user->get_shop_info();
					$banner_id       = isset( $store_info['banner'] ) ? $store_info['banner'] : 0;
					$store_name      = isset( $store_info['store_name'] ) ? esc_html( $store_info['store_name'] ) : __( 'N/A', 'wc-multivendor-marketplace' );
					$store_url       = wcfmmp_get_store_url( $store_id );
					$store_address   = $store_user->get_address_string(); 
					$banner_url      = ( $banner_id ) ? wp_get_attachment_image_src( $banner_id, $image_size ) : $WCFMmp->plugin_url . 'assets/images/default_banner.jpg';;
					$featured_store = get_user_meta( $store_id, 'wcfmmp_feature_store', true );
					?>

					<li class="wcfmmp-single-store woocommerce coloum-<?php echo $per_row; ?>">
						<div class="store-wrapper">
							<div class="store-content">
								<div class="store-info" style="background-image: url( '<?php echo is_array( $banner_url ) ? $banner_url[0] : $banner_url; ?>');">
									<div class="store-data-container">
										<div class="featured-favourite">
											<?php if ( ! empty( $featured_store ) && 'yes' == $featured_store ): ?>
												<div class="featured-label"><?php _e( 'Verified', 'wc-multivendor-marketplace' ); ?></div>
											<?php endif ?>
										</div>

										<div class="store-data">
											<h2><a href="<?php echo $store_url; ?>"><?php echo $store_name; ?></a></h2>

											<?php $store_user->show_star_rating(); ?>
											
											<?php do_action( 'after_wcfmmp_store_list_rating', $store_id, $store_info ); ?>

											<?php if ( $store_address ): ?>
												<p class="store-address"><?php echo $store_address; ?></p>
											<?php endif ?>

											<?php if ( !empty( $store_info['phone'] ) ) { ?>
												<p class="store-phone">
													<i class="fa fa-phone" aria-hidden="true"></i> <?php echo esc_html( $store_info['phone'] ); ?>
												</p>
											<?php } ?>
											<?php do_action( 'wcfmmp_store_list_after_store_info', $store_id, $store_info ); ?>
										</div>
									</div>
								</div>
							</div>
							<div class="store-footer">
								<div class="store-avatar">
									<?php echo get_avatar( $store_id, 150 ); ?>
								</div>
								<a href="<?php echo $store_url; ?>" class="wcfmmp-visit-store"><?php _e( 'Visit Store', 'wc-multivendor-marketplace' ); ?></a>
								<?php do_action( 'wcfmmp_store_list_footer', $store_id, $store_info ); ?>
							</div>
						</div>
					</li>

				<?php } ?>
				<div class="wcfm-clearfix"></div>
			</ul> <!-- .wcfmmp-store-wrap -->

			<?php
			$all_stores = $WCFM->wcfm_vendor_support->wcfm_get_vendor_list( true, '', '', $search_query );
			unset($all_stores[0]);
			$user_count   = count($all_stores);
			$num_of_pages = ceil( $user_count / $limit );

			if ( $num_of_pages > 1 ) {
				$args = array(
						'paged'           => $paged,
						'search_query'    => $search_query,
						'pagination_base' => $pagination_base,
						'num_of_pages'    => $num_of_pages,
				);
				$WCFMmp->template->get_template( 'shortcodes/wcfmmp-view-store-lists-pagination.php', $args );
			}
			?>

		<?php else:  ?>
			<p class="wcfmmp-error"><?php _e( 'No vendor found!', 'wc-multivendor-marketplace' ); ?></p>
		<?php endif; ?>
	</div>
</div>